@@ -1,4 +1,5 @@
 import math
+import deetly
 import pandas as pd
 
 from collections.abc import Sequence
@@ -13,6 +14,7 @@ from dataverk.elastic_search_updater import ElasticSearchUpdater
 from dataverk.connectors.elasticsearch import ElasticsearchConnector
 from dataverk.package_publisher import PackagePublisher
 from dataverk.utils.anonymization import anonymize_replace
+from dataverk.utils.metadata_utils import is_nav_environment, set_nav_config
 
 
 class Dataverk(DataverkBase):
@@ -210,11 +212,11 @@ class Dataverk(DataverkBase):
 
     def publish(self, datapackage):
 
-        # Try to get JSON representation in case datapackage is not a dict
-        try:
-            datapackage = datapackage.toJSON()     
-        except:
-            pass
+        if isinstance(datapackage, deetly.datapackage.Datapackage):
+            datapackage.datapackage_metadata = datapackage.toJSON()
+
+        if is_nav_environment():
+            set_nav_config(datapackage.datapackage_metadata)
 
         # Publish resources to buckets
         package_publisher = PackagePublisher(
