@@ -41,11 +41,11 @@ class ElasticSearchUpdater(DataverkBase):
             "license": self.datapackage_json.get("license",
                               {'name': 'CC BY 4.0', 'url': 'http://creativecommons.org/licenses/by/4.0/deed.no'}),
             "language": self.datapackage_json.get("language", "Norsk"),
-            "accrualPeriodicity": self.datapackage_json.get("accrualPeriodicity", ""),
-            "temporal": self.datapackage_json.get("temporal", ""),
+            "periodicity": self.datapackage_json.get("accrualPeriodicity", ""),
+            "temporal": self.datapackage_json.get("temporal", {}),
             "category": self.datapackage_json.get("category", ""),
             "status": self.datapackage_json.get("status", ""),
-            "rights": self.datapackage_json.get("rights", []),
+            "rights": self.datapackage_json.get("rights", ""),
             "byteSize": self.datapackage_json.get("byteSize", []),
             "provenance": self.datapackage_json.get("provenance", ""),
             "issued": self.datapackage_json.get("issued", datetime.now().isoformat()),
@@ -59,9 +59,10 @@ class ElasticSearchUpdater(DataverkBase):
             "publisher": self.datapackage_json.get("publisher",
                                 {'name': 'Arbeids- og velferdsetaten (NAV)', 'publisher_url': 'https://www.nav.no'}),
             "creator": self.datapackage_json.get("creator", {'name': 'NAV kunnskapsavdelingen', 'email': 'statistikk@nav.no'}),
-            "contactPoint": self.datapackage_json.get("contactPoint", []),
+            "contactPoint": self.datapackage_json.get("contactPoint", {}),
             "spatial": self.datapackage_json.get("spatial", []),
             "url": f"{self.datapackage_json.get('path', '')}/datapackage.json",
+            "uri": f"{self.datapackage_json.get('uri', '')}",
             "source": self.datapackage_json.get("source", []),
             "sample": self.datapackage_json.get("sample", []),
             "repo": self.datapackage_json.get("repo", ""),
